Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterGatewayControlServer(s grpc.ServiceRegistrar, srv GatewayControlServer)
- type GatewayControlClient
- type GatewayControlServer
- type GenerateCredentialsRequest
- func (*GenerateCredentialsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GenerateCredentialsRequest) GetForceUseAgent() bool
- func (x *GenerateCredentialsRequest) GetKubernetesNamespace() string
- func (x *GenerateCredentialsRequest) GetName() string
- func (x *GenerateCredentialsRequest) GetOperatingSystem() GenerateCredentialsRequest_OperatingSystem
- func (x *GenerateCredentialsRequest) GetVersion() string
- func (*GenerateCredentialsRequest) ProtoMessage()
- func (x *GenerateCredentialsRequest) ProtoReflect() protoreflect.Message
- func (x *GenerateCredentialsRequest) Reset()
- func (x *GenerateCredentialsRequest) String() string
- type GenerateCredentialsRequest_OperatingSystem
- func (GenerateCredentialsRequest_OperatingSystem) Descriptor() protoreflect.EnumDescriptor
- func (x GenerateCredentialsRequest_OperatingSystem) Enum() *GenerateCredentialsRequest_OperatingSystem
- func (GenerateCredentialsRequest_OperatingSystem) EnumDescriptor() ([]byte, []int)deprecated
- func (x GenerateCredentialsRequest_OperatingSystem) Number() protoreflect.EnumNumber
- func (x GenerateCredentialsRequest_OperatingSystem) String() string
- func (GenerateCredentialsRequest_OperatingSystem) Type() protoreflect.EnumType
- type GenerateCredentialsResponse
- func (*GenerateCredentialsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GenerateCredentialsResponse) GetEndpoint() string
- func (x *GenerateCredentialsResponse) GetKubeconfig() []byte
- func (*GenerateCredentialsResponse) ProtoMessage()
- func (x *GenerateCredentialsResponse) ProtoReflect() protoreflect.Message
- func (x *GenerateCredentialsResponse) Reset()
- func (x *GenerateCredentialsResponse) String() string
- type UnimplementedGatewayControlServer
- type UnsafeGatewayControlServer
Constants ¶
const (
GatewayControl_GenerateCredentials_FullMethodName = "/google.cloud.gkeconnect.gateway.v1.GatewayControl/GenerateCredentials"
)
Variables ¶
var ( GenerateCredentialsRequest_OperatingSystem_name = map[int32]string{ 0: "OPERATING_SYSTEM_UNSPECIFIED", 1: "OPERATING_SYSTEM_WINDOWS", } GenerateCredentialsRequest_OperatingSystem_value = map[string]int32{ "OPERATING_SYSTEM_UNSPECIFIED": 0, "OPERATING_SYSTEM_WINDOWS": 1, } )
Enum value maps for GenerateCredentialsRequest_OperatingSystem.
var File_google_cloud_gkeconnect_gateway_v1_control_proto protoreflect.FileDescriptor
var GatewayControl_ServiceDesc = grpc.ServiceDesc{ ServiceName: "google.cloud.gkeconnect.gateway.v1.GatewayControl", HandlerType: (*GatewayControlServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GenerateCredentials", Handler: _GatewayControl_GenerateCredentials_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "google/cloud/gkeconnect/gateway/v1/control.proto", }
GatewayControl_ServiceDesc is the grpc.ServiceDesc for GatewayControl service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterGatewayControlServer ¶
func RegisterGatewayControlServer(s grpc.ServiceRegistrar, srv GatewayControlServer)
Types ¶
type GatewayControlClient ¶
type GatewayControlClient interface {
// GenerateCredentials provides connection information that allows a user to
// access the specified membership using Connect Gateway.
GenerateCredentials(ctx context.Context, in *GenerateCredentialsRequest, opts ...grpc.CallOption) (*GenerateCredentialsResponse, error)
}
GatewayControlClient is the client API for GatewayControl service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewGatewayControlClient ¶
func NewGatewayControlClient(cc grpc.ClientConnInterface) GatewayControlClient
type GatewayControlServer ¶
type GatewayControlServer interface {
// GenerateCredentials provides connection information that allows a user to
// access the specified membership using Connect Gateway.
GenerateCredentials(context.Context, *GenerateCredentialsRequest) (*GenerateCredentialsResponse, error)
}
GatewayControlServer is the server API for GatewayControl service. All implementations should embed UnimplementedGatewayControlServer for forward compatibility
type GenerateCredentialsRequest ¶
type GenerateCredentialsRequest struct {
// Required. The Fleet membership resource.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Optional. Whether to force the use of Connect Agent-based transport.
//
// This will return a configuration that uses Connect Agent as the underlying
// transport mechanism for cluster types that would otherwise have used a
// different transport. Requires that Connect Agent be installed on the
// cluster. Setting this field to false is equivalent to not setting it.
ForceUseAgent bool `protobuf:"varint,2,opt,name=force_use_agent,json=forceUseAgent,proto3" json:"force_use_agent,omitempty"`
// Optional. The Connect Gateway version to be used in the resulting
// configuration.
//
// Leave this field blank to let the server choose the version (recommended).
Version string `protobuf:"bytes,3,opt,name=version,proto3" json:"version,omitempty"`
// Optional. The namespace to use in the kubeconfig context.
//
// If this field is specified, the server will set the `namespace` field in
// kubeconfig context. If not specified, the `namespace` field is omitted.
KubernetesNamespace string `protobuf:"bytes,4,opt,name=kubernetes_namespace,json=kubernetesNamespace,proto3" json:"kubernetes_namespace,omitempty"`
// Optional. The operating system where the kubeconfig will be used.
OperatingSystem GenerateCredentialsRequest_OperatingSystem `` /* 190-byte string literal not displayed */
// contains filtered or unexported fields
}
A request for connection information for a particular membership.
func (*GenerateCredentialsRequest) Descriptor
deprecated
func (*GenerateCredentialsRequest) Descriptor() ([]byte, []int)
Deprecated: Use GenerateCredentialsRequest.ProtoReflect.Descriptor instead.
func (*GenerateCredentialsRequest) GetForceUseAgent ¶
func (x *GenerateCredentialsRequest) GetForceUseAgent() bool
func (*GenerateCredentialsRequest) GetKubernetesNamespace ¶
func (x *GenerateCredentialsRequest) GetKubernetesNamespace() string
func (*GenerateCredentialsRequest) GetName ¶
func (x *GenerateCredentialsRequest) GetName() string
func (*GenerateCredentialsRequest) GetOperatingSystem ¶
func (x *GenerateCredentialsRequest) GetOperatingSystem() GenerateCredentialsRequest_OperatingSystem
func (*GenerateCredentialsRequest) GetVersion ¶
func (x *GenerateCredentialsRequest) GetVersion() string
func (*GenerateCredentialsRequest) ProtoMessage ¶
func (*GenerateCredentialsRequest) ProtoMessage()
func (*GenerateCredentialsRequest) ProtoReflect ¶
func (x *GenerateCredentialsRequest) ProtoReflect() protoreflect.Message
func (*GenerateCredentialsRequest) Reset ¶
func (x *GenerateCredentialsRequest) Reset()
func (*GenerateCredentialsRequest) String ¶
func (x *GenerateCredentialsRequest) String() string
type GenerateCredentialsRequest_OperatingSystem ¶
type GenerateCredentialsRequest_OperatingSystem int32
Operating systems requiring specialized kubeconfigs.
const ( // Generates a kubeconfig that works for all operating systems not defined // below. GenerateCredentialsRequest_OPERATING_SYSTEM_UNSPECIFIED GenerateCredentialsRequest_OperatingSystem = 0 // Generates a kubeconfig that is specifically designed to work with // Windows. GenerateCredentialsRequest_OPERATING_SYSTEM_WINDOWS GenerateCredentialsRequest_OperatingSystem = 1 )
func (GenerateCredentialsRequest_OperatingSystem) Descriptor ¶
func (GenerateCredentialsRequest_OperatingSystem) Descriptor() protoreflect.EnumDescriptor
func (GenerateCredentialsRequest_OperatingSystem) EnumDescriptor
deprecated
func (GenerateCredentialsRequest_OperatingSystem) EnumDescriptor() ([]byte, []int)
Deprecated: Use GenerateCredentialsRequest_OperatingSystem.Descriptor instead.
func (GenerateCredentialsRequest_OperatingSystem) Number ¶
func (x GenerateCredentialsRequest_OperatingSystem) Number() protoreflect.EnumNumber
func (GenerateCredentialsRequest_OperatingSystem) String ¶
func (x GenerateCredentialsRequest_OperatingSystem) String() string
func (GenerateCredentialsRequest_OperatingSystem) Type ¶
func (GenerateCredentialsRequest_OperatingSystem) Type() protoreflect.EnumType
type GenerateCredentialsResponse ¶
type GenerateCredentialsResponse struct {
// A full YAML kubeconfig in serialized format.
Kubeconfig []byte `protobuf:"bytes,1,opt,name=kubeconfig,proto3" json:"kubeconfig,omitempty"`
// The generated URI of the cluster as accessed through the Connect Gateway
// API.
Endpoint string `protobuf:"bytes,2,opt,name=endpoint,proto3" json:"endpoint,omitempty"`
// contains filtered or unexported fields
}
Connection information for a particular membership.
func (*GenerateCredentialsResponse) Descriptor
deprecated
func (*GenerateCredentialsResponse) Descriptor() ([]byte, []int)
Deprecated: Use GenerateCredentialsResponse.ProtoReflect.Descriptor instead.
func (*GenerateCredentialsResponse) GetEndpoint ¶
func (x *GenerateCredentialsResponse) GetEndpoint() string
func (*GenerateCredentialsResponse) GetKubeconfig ¶
func (x *GenerateCredentialsResponse) GetKubeconfig() []byte
func (*GenerateCredentialsResponse) ProtoMessage ¶
func (*GenerateCredentialsResponse) ProtoMessage()
func (*GenerateCredentialsResponse) ProtoReflect ¶
func (x *GenerateCredentialsResponse) ProtoReflect() protoreflect.Message
func (*GenerateCredentialsResponse) Reset ¶
func (x *GenerateCredentialsResponse) Reset()
func (*GenerateCredentialsResponse) String ¶
func (x *GenerateCredentialsResponse) String() string
type UnimplementedGatewayControlServer ¶
type UnimplementedGatewayControlServer struct {
}
UnimplementedGatewayControlServer should be embedded to have forward compatible implementations.
func (UnimplementedGatewayControlServer) GenerateCredentials ¶
func (UnimplementedGatewayControlServer) GenerateCredentials(context.Context, *GenerateCredentialsRequest) (*GenerateCredentialsResponse, error)
type UnsafeGatewayControlServer ¶ added in v0.12.5
type UnsafeGatewayControlServer interface {
// contains filtered or unexported methods
}
UnsafeGatewayControlServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to GatewayControlServer will result in compilation errors.